==> haskell-clientsession-0.9.1.2-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.2
id: clientsession-0.9.1.2-F146WtHIUnMILuZ4IVecAE
key: clientsession-0.9.1.2-F146WtHIUnMILuZ4IVecAE
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
abi: be0c58dff3bbed5b7f43192526523d67
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/clientsession-0.9.1.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/clientsession-0.9.1.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/clientsession-0.9.1.2
hs-libraries: HSclientsession-0.9.1.2-F146WtHIUnMILuZ4IVecAE
depends:
    base-4.9.0.0 base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
    cipher-aes-0.2.11-EQX7Hl7R1DG74OgDovRVQ9
    cprng-aes-0.6.1-4vIp9M79FFGDH3p3k7idwe
    crypto-api-0.13.2-BMG9I4cfxb91dOhyZw6iKb
    crypto-random-0.0.9-Jxwl2P30S0cADnfhVJnwtl directory-1.2.6.2
    entropy-0.3.7-54dsRvsNlllHvcIX99CGiD
    setenv-0.1.1.3-5zeeXxY3qb3AsPnIgczcsm
    skein-1.0.9.4-GwPkvQegVz25q0X9Jt5arI
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clientsession-0.9.1.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.2
id: clientsession-0.9.1.2-E8NZpBho6DoBMfOXGiX614
key: clientsession-0.9.1.2-E8NZpBho6DoBMfOXGiX614
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
abi: b90bc349da8a6b750cc2ff925f9aca3a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/clientsession-0.9.1.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/clientsession-0.9.1.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/clientsession-0.9.1.2
hs-libraries: HSclientsession-0.9.1.2-E8NZpBho6DoBMfOXGiX614
depends:
    base-4.9.0.0 base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
    cipher-aes-0.2.11-4JSFAW5Er301EO5ypFfPZ3
    cprng-aes-0.6.1-ElzXuMli7WyAHsEinA5oq
    crypto-api-0.13.2-BMG9I4cfxb91dOhyZw6iKb
    crypto-random-0.0.9-JOU8lue6KbLEq1yW10dkyV directory-1.2.6.2
    entropy-0.3.7-54dsRvsNlllHvcIX99CGiD
    setenv-0.1.1.3-5zeeXxY3qb3AsPnIgczcsm
    skein-1.0.9.4-GwPkvQegVz25q0X9Jt5arI
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
